// -------------------------------------------------------------------------------------------------
//          _____          _______                                   ____   _____
//      ,-:` \;',`'-,     |__  _(_)                                 |___ \ |  __ \
//    .'-;_,;  ':-;_,'.      | | _  _ __   _ __ ___    __ _  _ __     __) || |  | |
//   /;   '/    ,  _`.-\     | || || '_ \ | '_ ` _ \  / _` || '_ \   |__ < | |  | |
//  | '`. (`     /` ` \`|    | || || | | || | | | | || (_| || | | |  ___) || |__| |
//  |:.  `\`-.   \_   / |    |_||_||_| |_||_| |_| |_| \__,_||_| |_| |____/ |_____/
//  |     (   `,  .`\ ;'|
//   \     | .'     `-'/      Realtime terrain processing, rendering and analysis
//    `.   ;/        .'
//      `'-._____.-'`             http://www.tinman3d.com - info@tinman3d.com
// -------------------------------------------------------------------------------------------------
// FILE:       SR_Example.hlsl
// -------------------------------------------------------------------------------------------------
// COPYRIGHT:  Matthias Englert, me@tinman3d.com
// -------------------------------------------------------------------------------------------------
// AUTHOR(s):  Matthias Englert, me@tinman3d.com
// -------------------------------------------------------------------------------------------------
// DISCLAIMER: This source  code is  provided "as  is" and  without warranties  as to performance or
//             merchantability. The  author and/or  distributors of  this source  code may have made
//             statements about this source code.  Any such statements do not  constitute warranties
//             and shall not be  relied on by  the user in deciding whether to use this source code.
//             This source code is provided without any expressed or implied warranties  whatsoever.
//             Because of the diversity of conditions and hardware under which this source code  may
//             be used,  no warranty  of fitness  for a  particular purpose  is offered. The user is
//             advised to test the source code thoroughly before relying on it. The user must assume
//             the entire risk of using the source code.
// -------------------------------------------------------------------------------------------------

#ifndef TINMAN__DEMO__SR_EXAMPLE
#define TINMAN__DEMO__SR_EXAMPLE

#include "../../GpuX.hlsl"

// -------------------------------------------------------------------------------------------------
// Shader Resources
// -------------------------------------------------------------------------------------------------

/*!
 * @brief A read-only array of 32-bit integer values.
 */
ARRAY(g_array_R);

/*!
 * @brief A read-write array of 32-bit integer values.
 */
ARRAY_RW(g_array_RW);

/*!
 * @brief A read-only structured buffer.
 */
BUFFER(int, g_buffer_R);

/*!
 * @brief A read-write structured buffer.
 */
BUFFER_RW(int, g_buffer_RW);

/*!
 * @brief A two-dimensional texture.
 */
TEXTURE_2D(float, g_texture_2D_1);

/*!
 * @brief An array of two-dimensional textures.
 */
TEXTURE_2D(float, g_texture_2D_1_N)[2];

/*!
 * @brief A two-dimensional texture.
 */
TEXTURE_2D(float2, g_texture_2D_2);

/*!
 * @brief An array of two-dimensional textures.
 */
TEXTURE_2D(float2, g_texture_2D_2_N)[2];

/*!
 * @brief A two-dimensional texture.
 */
TEXTURE_2D(float3, g_texture_2D_3);

/*!
 * @brief An array of two-dimensional textures.
 */
TEXTURE_2D(float3, g_texture_2D_3_N)[2];

/*!
 * @brief A two-dimensional texture.
 */
TEXTURE_2D(float4, g_texture_2D_4);

/*!
 * @brief An array of two-dimensional textures.
 */
TEXTURE_2D(float4, g_texture_2D_4_N)[2];

/*!
 * @brief A two-dimensional texture array.
 */
TEXTURE_2D_ARRAY(float, g_texture_2D_Array_1);

/*!
 * @brief An array of two-dimensional texture arrays.
 */
TEXTURE_2D_ARRAY(float, g_texture_2D_Array_1_N)[2];

/*!
 * @brief A two-dimensional texture array.
 */
TEXTURE_2D_ARRAY(float2, g_texture_2D_Array_2);

/*!
 * @brief An array of two-dimensional texture arrays.
 */
TEXTURE_2D_ARRAY(float2, g_texture_2D_Array_2_N)[2];

/*!
 * @brief A two-dimensional texture array.
 */
TEXTURE_2D_ARRAY(float3, g_texture_2D_Array_3);

/*!
 * @brief An array of two-dimensional texture arrays.
 */
TEXTURE_2D_ARRAY(float3, g_texture_2D_Array_3_N)[2];

/*!
 * @brief A two-dimensional texture array.
 */
TEXTURE_2D_ARRAY(float4, g_texture_2D_Array_4);

/*!
 * @brief An array of two-dimensional texture arrays.
 */
TEXTURE_2D_ARRAY(float4, g_texture_2D_Array_4_N)[2];

/*!
 * @brief A two-dimensional texture buffer with read-write access.
 */
TEXTURE_2D_RW(int, g_texture_2D_RW);

/*!
 * @brief A cubemap texture.
 */
TEXTURE_CUBE(float, g_texture_Cube_1);

/*!
 * @brief An array of cubemap textures.
 */
TEXTURE_CUBE(float, g_texture_Cube_1_N)[2];

/*!
 * @brief A cubemap texture.
 */
TEXTURE_CUBE(float2, g_texture_Cube_2);

/*!
 * @brief An array of cubemap textures.
 */
TEXTURE_CUBE(float2, g_texture_Cube_2_N)[2];

/*!
 * @brief A cubemap texture.
 */
TEXTURE_CUBE(float3, g_texture_Cube_3);

/*!
 * @brief An array of cubemap textures.
 */
TEXTURE_CUBE(float3, g_texture_Cube_3_N)[2];

/*!
 * @brief A cubemap texture.
 */
TEXTURE_CUBE(float4, g_texture_Cube_4);

/*!
 * @brief An array of cubemap textures.
 */
TEXTURE_CUBE(float4, g_texture_Cube_4_N)[2];

#endif
