// -------------------------------------------------------------------------------------------------
//          _____          _______                                   ____   _____
//      ,-:` \;',`'-,     |__  _(_)                                 |___ \ |  __ \
//    .'-;_,;  ':-;_,'.      | | _  _ __   _ __ ___    __ _  _ __     __) || |  | |
//   /;   '/    ,  _`.-\     | || || '_ \ | '_ ` _ \  / _` || '_ \   |__ < | |  | |
//  | '`. (`     /` ` \`|    | || || | | || | | | | || (_| || | | |  ___) || |__| |
//  |:.  `\`-.   \_   / |    |_||_||_| |_||_| |_| |_| \__,_||_| |_| |____/ |_____/
//  |     (   `,  .`\ ;'|
//   \     | .'     `-'/      Realtime terrain processing, rendering and analysis
//    `.   ;/        .'
//      `'-._____.-'`             http://www.tinman3d.com - info@tinman3d.com
// -------------------------------------------------------------------------------------------------
// FILE:       Graphics.PS.hlsl
// -------------------------------------------------------------------------------------------------
// COPYRIGHT:  Matthias Englert, me@tinman3d.com
// -------------------------------------------------------------------------------------------------
// AUTHOR(s):  Matthias Englert, me@tinman3d.com
// -------------------------------------------------------------------------------------------------
// DISCLAIMER: This source  code is  provided "as  is" and  without warranties  as to performance or
//             merchantability. The  author and/or  distributors of  this source  code may have made
//             statements about this source code.  Any such statements do not  constitute warranties
//             and shall not be  relied on by  the user in deciding whether to use this source code.
//             This source code is provided without any expressed or implied warranties  whatsoever.
//             Because of the diversity of conditions and hardware under which this source code  may
//             be used,  no warranty  of fitness  for a  particular purpose  is offered. The user is
//             advised to test the source code thoroughly before relying on it. The user must assume
//             the entire risk of using the source code.
// -------------------------------------------------------------------------------------------------

#ifndef TINMAN__GRAPHICS__GRAPHICS_PS
#define TINMAN__GRAPHICS__GRAPHICS_PS

#include "../../GpuX.hlsl"
#include "../Configuration.hlsl"
#include "../PS_Out_Target.hlsl"
#include "../Util.hlsl"
#include "CB_Graphics_Dynamic.hlsl"
#include "CB_Graphics_Static.hlsl"
#include "Graphics.hlsl"
#include "SR_Graphics.hlsl"
#include "VS_Out.hlsl"

// -------------------------------------------------------------------------------------------------
// Pixel Shader 'Graphics.PS'
// -------------------------------------------------------------------------------------------------

/*!
 * @brief The pixel shader for 'IGraphicsEffect'.
 *
 * @param data The shader input.
 *
 * @returns The shader output.
 */
PS_Out_Target main(VS_Out data)
{
  PS_Out_Target result;
  float color[7];
  float4 temp;

  temp = gxTexture2DArray(g_image, g_slice, data.Coords);
  color[0] = temp.r;
  color[1] = temp.g;
  color[2] = temp.b;
  color[3] = temp.a;
  color[4] = 0.0;
  color[5] = 1.0;
  color[6] = dot(temp.rgb, Luminance);
  temp.r = color[g_colors.x];
  temp.g = color[g_colors.y];
  temp.b = color[g_colors.z];
  temp.a = color[g_colors.w];
  result.Color = temp * data.Color;

  if (THICK_LINES)
  {
    if (g_lineThickness.z > 0.0)
    {
      result.Color.a = saturate(1.0 - (length(data.Clip) - 1.0) / g_lineThickness.z);
    }
  }

  if (g_screenMask.z > 0.0)
  {
    result.Color.a *= gxTexture2D(g_imageMask, float2((data.Screen.x - g_screenMask.x) /
        g_screenMask.z, (data.Screen.y - g_screenMask.y) / g_screenMask.w));
  }

  return result;
}

#endif
