// -------------------------------------------------------------------------------------------------
//          _____          _______                                   ____   _____
//      ,-:` \;',`'-,     |__  _(_)                                 |___ \ |  __ \
//    .'-;_,;  ':-;_,'.      | | _  _ __   _ __ ___    __ _  _ __     __) || |  | |
//   /;   '/    ,  _`.-\     | || || '_ \ | '_ ` _ \  / _` || '_ \   |__ < | |  | |
//  | '`. (`     /` ` \`|    | || || | | || | | | | || (_| || | | |  ___) || |__| |
//  |:.  `\`-.   \_   / |    |_||_||_| |_||_| |_| |_| \__,_||_| |_| |____/ |_____/
//  |     (   `,  .`\ ;'|
//   \     | .'     `-'/      Realtime terrain processing, rendering and analysis
//    `.   ;/        .'
//      `'-._____.-'`             http://www.tinman3d.com - info@tinman3d.com
// -------------------------------------------------------------------------------------------------
// FILE:       VS_In_Instance.hlsl
// -------------------------------------------------------------------------------------------------
// COPYRIGHT:  Matthias Englert, me@tinman3d.com
// -------------------------------------------------------------------------------------------------
// AUTHOR(s):  Matthias Englert, me@tinman3d.com
// -------------------------------------------------------------------------------------------------
// DISCLAIMER: This source  code is  provided "as  is" and  without warranties  as to performance or
//             merchantability. The  author and/or  distributors of  this source  code may have made
//             statements about this source code.  Any such statements do not  constitute warranties
//             and shall not be  relied on by  the user in deciding whether to use this source code.
//             This source code is provided without any expressed or implied warranties  whatsoever.
//             Because of the diversity of conditions and hardware under which this source code  may
//             be used,  no warranty  of fitness  for a  particular purpose  is offered. The user is
//             advised to test the source code thoroughly before relying on it. The user must assume
//             the entire risk of using the source code.
// -------------------------------------------------------------------------------------------------

#ifndef TINMAN__MODEL__VS_IN_INSTANCE
#define TINMAN__MODEL__VS_IN_INSTANCE

#include "../../GpuX.hlsl"

// -------------------------------------------------------------------------------------------------
// Shader Parameters
// -------------------------------------------------------------------------------------------------

/*!
 * @brief Vertex shader input for 'IModelRendererEffect'.
 */
struct VS_In_Instance
{
  /*!
   * @brief Modulation factors for color and ambient occlusion.
   */
  float4 Color SEMANTIC_COLOR(1);

  /*!
   * @brief Tangent of orientation frame.
   */
  float3 Matrix0 SEMANTIC_TANGENT(2);

  /*!
   * @brief Bitangent of orientation frame.
   */
  float3 Matrix1 SEMANTIC_TANGENT(3);

  /*!
   * @brief Position offset.
   */
  float3 Position SEMANTIC_POSITION(2);

  /*!
   * @brief Vertex color scale + position interpretation.
   */
  float Intensity SEMANTIC_TEXCOORD(3);

  /*!
   * @brief Uniform scale factor.
   */
  float Scale SEMANTIC_TEXCOORD(2);
};

#endif
