// -------------------------------------------------------------------------------------------------
//          _____          _______                                   ____   _____
//      ,-:` \;',`'-,     |__  _(_)                                 |___ \ |  __ \
//    .'-;_,;  ':-;_,'.      | | _  _ __   _ __ ___    __ _  _ __     __) || |  | |
//   /;   '/    ,  _`.-\     | || || '_ \ | '_ ` _ \  / _` || '_ \   |__ < | |  | |
//  | '`. (`     /` ` \`|    | || || | | || | | | | || (_| || | | |  ___) || |__| |
//  |:.  `\`-.   \_   / |    |_||_||_| |_||_| |_| |_| \__,_||_| |_| |____/ |_____/
//  |     (   `,  .`\ ;'|
//   \     | .'     `-'/      Realtime terrain processing, rendering and analysis
//    `.   ;/        .'
//      `'-._____.-'`             http://www.tinman3d.com - info@tinman3d.com
// -------------------------------------------------------------------------------------------------
// FILE:       Process.PS_Transparency.hlsl
// -------------------------------------------------------------------------------------------------
// COPYRIGHT:  Matthias Englert, me@tinman3d.com
// -------------------------------------------------------------------------------------------------
// AUTHOR(s):  Matthias Englert, me@tinman3d.com
// -------------------------------------------------------------------------------------------------
// DISCLAIMER: This source  code is  provided "as  is" and  without warranties  as to performance or
//             merchantability. The  author and/or  distributors of  this source  code may have made
//             statements about this source code.  Any such statements do not  constitute warranties
//             and shall not be  relied on by  the user in deciding whether to use this source code.
//             This source code is provided without any expressed or implied warranties  whatsoever.
//             Because of the diversity of conditions and hardware under which this source code  may
//             be used,  no warranty  of fitness  for a  particular purpose  is offered. The user is
//             advised to test the source code thoroughly before relying on it. The user must assume
//             the entire risk of using the source code.
// -------------------------------------------------------------------------------------------------

#ifndef TINMAN__PROCESS__PROCESS_PS_TRANSPARENCY
#define TINMAN__PROCESS__PROCESS_PS_TRANSPARENCY

#include "../../GpuX.hlsl"
#include "../Configuration.hlsl"
#include "../PS_Out_Target.hlsl"
#include "CB_Process_Static.hlsl"
#include "Process.hlsl"
#include "SR_Process.hlsl"
#include "VS_Out.hlsl"

// -------------------------------------------------------------------------------------------------
// Pixel Shader 'Process.PS_Transparency'
// -------------------------------------------------------------------------------------------------

/*!
 * @brief The pixel shader for 'ProcessParameters.PassTransparency'.
 *
 * @param data The shader input.
 *
 * @returns The shader output.
 */
PS_Out_Target main(VS_Out data)
{
  PS_Out_Target result;
  float4 accum;
  float weight;

  // Apply pixel offset to align pixels and texels.

  data.Coords += g_offset * PIXEL_OFFSET;
  accum = gxTextures2D(g_input, 0, data.Coords);
  weight = gxTextures2D(g_input, 1, data.Coords).r;
  result.Color = float4(accum.rgb / weight, 1.0 - accum.a);

  return result;
}

#endif
