// -------------------------------------------------------------------------------------------------
//          _____          _______                                   ____   _____
//      ,-:` \;',`'-,     |__  _(_)                                 |___ \ |  __ \
//    .'-;_,;  ':-;_,'.      | | _  _ __   _ __ ___    __ _  _ __     __) || |  | |
//   /;   '/    ,  _`.-\     | || || '_ \ | '_ ` _ \  / _` || '_ \   |__ < | |  | |
//  | '`. (`     /` ` \`|    | || || | | || | | | | || (_| || | | |  ___) || |__| |
//  |:.  `\`-.   \_   / |    |_||_||_| |_||_| |_| |_| \__,_||_| |_| |____/ |_____/
//  |     (   `,  .`\ ;'|
//   \     | .'     `-'/      Realtime terrain processing, rendering and analysis
//    `.   ;/        .'
//      `'-._____.-'`             http://www.tinman3d.com - info@tinman3d.com
// -------------------------------------------------------------------------------------------------
// FILE:       Process.VS.hlsl
// -------------------------------------------------------------------------------------------------
// COPYRIGHT:  Matthias Englert, me@tinman3d.com
// -------------------------------------------------------------------------------------------------
// AUTHOR(s):  Matthias Englert, me@tinman3d.com
// -------------------------------------------------------------------------------------------------
// DISCLAIMER: This source  code is  provided "as  is" and  without warranties  as to performance or
//             merchantability. The  author and/or  distributors of  this source  code may have made
//             statements about this source code.  Any such statements do not  constitute warranties
//             and shall not be  relied on by  the user in deciding whether to use this source code.
//             This source code is provided without any expressed or implied warranties  whatsoever.
//             Because of the diversity of conditions and hardware under which this source code  may
//             be used,  no warranty  of fitness  for a  particular purpose  is offered. The user is
//             advised to test the source code thoroughly before relying on it. The user must assume
//             the entire risk of using the source code.
// -------------------------------------------------------------------------------------------------

#ifndef TINMAN__PROCESS__PROCESS_VS
#define TINMAN__PROCESS__PROCESS_VS

#include "../../GpuX.hlsl"
#include "Process.hlsl"
#include "VS_In.hlsl"
#include "VS_Out.hlsl"

// -------------------------------------------------------------------------------------------------
// Vertex Shader 'Process.VS'
// -------------------------------------------------------------------------------------------------

/*!
 * @brief The vertex shader that sets up the screen quad for pixel-perfect processing.
 *
 * @param data The shader input.
 *
 * @returns The shader output.
 */
VS_Out main(VS_In data)
{
  VS_Out result;

  // The clip coordinates (-1,+1) correspond to the center of the top-left pixel
  // (PixelOffset == 0.5) or its top-left corner (PixelOffset == 0).

  result.Position = float4(data.Position, 1);

  // The texture coordinate (0,0) represents the top-left corner of the top-left pixel.

  result.Coords = (data.Position.xy + 1.0) * 0.5;
  result.Coords.y = 1.0 - result.Coords.y;

  return result;
}

#endif
