// -------------------------------------------------------------------------------------------------
//          _____          _______                                   ____   _____
//      ,-:` \;',`'-,     |__  _(_)                                 |___ \ |  __ \
//    .'-;_,;  ':-;_,'.      | | _  _ __   _ __ ___    __ _  _ __     __) || |  | |
//   /;   '/    ,  _`.-\     | || || '_ \ | '_ ` _ \  / _` || '_ \   |__ < | |  | |
//  | '`. (`     /` ` \`|    | || || | | || | | | | || (_| || | | |  ___) || |__| |
//  |:.  `\`-.   \_   / |    |_||_||_| |_||_| |_| |_| \__,_||_| |_| |____/ |_____/
//  |     (   `,  .`\ ;'|
//   \     | .'     `-'/      Realtime terrain processing, rendering and analysis
//    `.   ;/        .'
//      `'-._____.-'`             http://www.tinman3d.com - info@tinman3d.com
// -------------------------------------------------------------------------------------------------
// FILE:       Renderer.PS.hlsl
// -------------------------------------------------------------------------------------------------
// COPYRIGHT:  Matthias Englert, me@tinman3d.com
// -------------------------------------------------------------------------------------------------
// AUTHOR(s):  Matthias Englert, me@tinman3d.com
// -------------------------------------------------------------------------------------------------
// DISCLAIMER: This source  code is  provided "as  is" and  without warranties  as to performance or
//             merchantability. The  author and/or  distributors of  this source  code may have made
//             statements about this source code.  Any such statements do not  constitute warranties
//             and shall not be  relied on by  the user in deciding whether to use this source code.
//             This source code is provided without any expressed or implied warranties  whatsoever.
//             Because of the diversity of conditions and hardware under which this source code  may
//             be used,  no warranty  of fitness  for a  particular purpose  is offered. The user is
//             advised to test the source code thoroughly before relying on it. The user must assume
//             the entire risk of using the source code.
// -------------------------------------------------------------------------------------------------

#ifndef TINMAN__RENDERER__RENDERER_PS
#define TINMAN__RENDERER__RENDERER_PS

#include "../../GpuX.hlsl"
#include "../Camera.hlsl"
#include "../Configuration.hlsl"
#include "../PS_Out_TargetDepthLess.hlsl"
#include "CB_Renderer_Dynamic.hlsl"
#include "Renderer.hlsl"
#include "VS_Out.hlsl"

// -------------------------------------------------------------------------------------------------
// Pixel Shader 'Renderer.PS'
// -------------------------------------------------------------------------------------------------

/*!
 * @brief The default pixel shader.
 *
 * @param data The shader input.
 *
 * @returns The shader output.
 */
PS_Out_TargetDepthLess main(VS_Out data)
{
  PS_Out_TargetDepthLess result;

  result.Color = data.Color;
  result.Depth = ComputeDepth(data.LinearZ);

  if (THICK_LINES)
  {
    if (g_lineThickness.z > 0.0)
    {
      result.Color.a = saturate(1.0 - (length(data.Clip) - 1.0) / g_lineThickness.z);
    }
  }

  return result;
}

#endif
