// -------------------------------------------------------------------------------------------------
//          _____          _______                                   ____   _____
//      ,-:` \;',`'-,     |__  _(_)                                 |___ \ |  __ \
//    .'-;_,;  ':-;_,'.      | | _  _ __   _ __ ___    __ _  _ __     __) || |  | |
//   /;   '/    ,  _`.-\     | || || '_ \ | '_ ` _ \  / _` || '_ \   |__ < | |  | |
//  | '`. (`     /` ` \`|    | || || | | || | | | | || (_| || | | |  ___) || |__| |
//  |:.  `\`-.   \_   / |    |_||_||_| |_||_| |_| |_| \__,_||_| |_| |____/ |_____/
//  |     (   `,  .`\ ;'|
//   \     | .'     `-'/      Realtime terrain processing, rendering and analysis
//    `.   ;/        .'
//      `'-._____.-'`             http://www.tinman3d.com - info@tinman3d.com
// -------------------------------------------------------------------------------------------------
// FILE:       Sky.PS_Map.hlsl
// -------------------------------------------------------------------------------------------------
// COPYRIGHT:  Matthias Englert, me@tinman3d.com
// -------------------------------------------------------------------------------------------------
// AUTHOR(s):  Matthias Englert, me@tinman3d.com
// -------------------------------------------------------------------------------------------------
// DISCLAIMER: This source  code is  provided "as  is" and  without warranties  as to performance or
//             merchantability. The  author and/or  distributors of  this source  code may have made
//             statements about this source code.  Any such statements do not  constitute warranties
//             and shall not be  relied on by  the user in deciding whether to use this source code.
//             This source code is provided without any expressed or implied warranties  whatsoever.
//             Because of the diversity of conditions and hardware under which this source code  may
//             be used,  no warranty  of fitness  for a  particular purpose  is offered. The user is
//             advised to test the source code thoroughly before relying on it. The user must assume
//             the entire risk of using the source code.
// -------------------------------------------------------------------------------------------------

#ifndef TINMAN__SKY__SKY_PS_MAP
#define TINMAN__SKY__SKY_PS_MAP

#include "../../GpuX.hlsl"
#include "../CB_Camera_Static.hlsl"
#include "../CB_Lighting_Static.hlsl"
#include "../Lighting.hlsl"
#include "../PS_Out_Target.hlsl"
#include "CB_Sky_Static.hlsl"
#include "Sky.hlsl"
#include "VS_Out.hlsl"

// -------------------------------------------------------------------------------------------------
// Pixel Shader 'Sky.PS_Map'
// -------------------------------------------------------------------------------------------------

/*!
 * @brief The pixel shader for 'SkyParameters.PassEnvironmentMap'.
 *
 * @param data The shader input.
 *
 * @returns The shader output.
 */
PS_Out_Target main(VS_Out data)
{
  PS_Out_Target result;
  float4 temp;
  float4 eye;
  float4 color;

  // Compute terrain-space vector for current screen pixel.

  temp = mul(g_viewProjectionMatrix[1], float4(data.Coords, 0, 1));
  temp /= temp.w;
  eye = mul(g_viewProjectionMatrix[1], float4(data.Coords, 0.1, 1));
  eye /= eye.w;
  eye -= temp;

  // Sample environment map, then apply environment scale and tone mapping.

  color = EnvironmentSampleSeamless(CubemapWarp(mul(g_lightSpace, eye.xyz), g_horizon), 0.0);
  result.Color.rgb = ComputeToneMap(color.rgb);
  result.Color.a = color.a;
  result.Color *= g_skyColor;

  return result;
}

#endif
