// -------------------------------------------------------------------------------------------------
//          _____          _______                                   ____   _____
//      ,-:` \;',`'-,     |__  _(_)                                 |___ \ |  __ \
//    .'-;_,;  ':-;_,'.      | | _  _ __   _ __ ___    __ _  _ __     __) || |  | |
//   /;   '/    ,  _`.-\     | || || '_ \ | '_ ` _ \  / _` || '_ \   |__ < | |  | |
//  | '`. (`     /` ` \`|    | || || | | || | | | | || (_| || | | |  ___) || |__| |
//  |:.  `\`-.   \_   / |    |_||_||_| |_||_| |_| |_| \__,_||_| |_| |____/ |_____/
//  |     (   `,  .`\ ;'|
//   \     | .'     `-'/      Realtime terrain processing, rendering and analysis
//    `.   ;/        .'
//      `'-._____.-'`             http://www.tinman3d.com - info@tinman3d.com
// -------------------------------------------------------------------------------------------------
// FILE:       GS_In_Material.hlsl
// -------------------------------------------------------------------------------------------------
// COPYRIGHT:  Matthias Englert, me@tinman3d.com
// -------------------------------------------------------------------------------------------------
// AUTHOR(s):  Matthias Englert, me@tinman3d.com
// -------------------------------------------------------------------------------------------------
// DISCLAIMER: This source  code is  provided "as  is" and  without warranties  as to performance or
//             merchantability. The  author and/or  distributors of  this source  code may have made
//             statements about this source code.  Any such statements do not  constitute warranties
//             and shall not be  relied on by  the user in deciding whether to use this source code.
//             This source code is provided without any expressed or implied warranties  whatsoever.
//             Because of the diversity of conditions and hardware under which this source code  may
//             be used,  no warranty  of fitness  for a  particular purpose  is offered. The user is
//             advised to test the source code thoroughly before relying on it. The user must assume
//             the entire risk of using the source code.
// -------------------------------------------------------------------------------------------------

#ifndef TINMAN__TERRAIN__GS_IN_MATERIAL
#define TINMAN__TERRAIN__GS_IN_MATERIAL

#include "../../GpuX.hlsl"
#include "DisplacementFixed.hlsl"

// -------------------------------------------------------------------------------------------------
// Shader Parameters
// -------------------------------------------------------------------------------------------------

/*!
 * @brief The geometry shader input.
 */
struct GS_In_Material
{
  /*!
   * @brief The vertex color.
   */
  float4 Color SEMANTIC_COLOR(0);

  /*!
   * @brief The material weights of the input material token.
   */
  float4 WeightsA SEMANTIC_COLOR(1);

  /*!
   * @brief The material weights of the current set of material textures.
   */
  float4 WeightsB SEMANTIC_COLOR(2);

  /*!
   * @brief The fixed displacement data.
   */
  DisplacementFixed Fixed;
};

#endif
