// -------------------------------------------------------------------------------------------------
//          _____          _______                                   ____   _____
//      ,-:` \;',`'-,     |__  _(_)                                 |___ \ |  __ \
//    .'-;_,;  ':-;_,'.      | | _  _ __   _ __ ___    __ _  _ __     __) || |  | |
//   /;   '/    ,  _`.-\     | || || '_ \ | '_ ` _ \  / _` || '_ \   |__ < | |  | |
//  | '`. (`     /` ` \`|    | || || | | || | | | | || (_| || | | |  ___) || |__| |
//  |:.  `\`-.   \_   / |    |_||_||_| |_||_| |_| |_| \__,_||_| |_| |____/ |_____/
//  |     (   `,  .`\ ;'|
//   \     | .'     `-'/      Realtime terrain processing, rendering and analysis
//    `.   ;/        .'
//      `'-._____.-'`             http://www.tinman3d.com - info@tinman3d.com
// -------------------------------------------------------------------------------------------------
// FILE:       PS_In_Decal.hlsl
// -------------------------------------------------------------------------------------------------
// COPYRIGHT:  Matthias Englert, me@tinman3d.com
// -------------------------------------------------------------------------------------------------
// AUTHOR(s):  Matthias Englert, me@tinman3d.com
// -------------------------------------------------------------------------------------------------
// DISCLAIMER: This source  code is  provided "as  is" and  without warranties  as to performance or
//             merchantability. The  author and/or  distributors of  this source  code may have made
//             statements about this source code.  Any such statements do not  constitute warranties
//             and shall not be  relied on by  the user in deciding whether to use this source code.
//             This source code is provided without any expressed or implied warranties  whatsoever.
//             Because of the diversity of conditions and hardware under which this source code  may
//             be used,  no warranty  of fitness  for a  particular purpose  is offered. The user is
//             advised to test the source code thoroughly before relying on it. The user must assume
//             the entire risk of using the source code.
// -------------------------------------------------------------------------------------------------

#ifndef TINMAN__TERRAIN__PS_IN_DECAL
#define TINMAN__TERRAIN__PS_IN_DECAL

#include "../../GpuX.hlsl"

// -------------------------------------------------------------------------------------------------
// Shader Parameters
// -------------------------------------------------------------------------------------------------

/*!
 * @brief Pixel shader input for 'TerrainParameters.PassDecal'.
 */
struct PS_In_Decal
{
  /*!
   * @brief The camera distance.
   */
  float Distance SEMANTIC_TEXCOORD(1);

  /*!
   * @brief The diffuse color.
   */
  float4 Color SEMANTIC_COLOR(0);

  /*!
   * @brief The vertex position.
   */
  float4 Position SEMANTIC_SYSTEM_POSITION(0);

  /*!
   * @brief The shadow coordinates.
   */
  float4 Shadow SEMANTIC_TEXCOORD(2);

  /*!
   * @brief The eye vector.
   */
  float3 Eye SEMANTIC_NORMAL(0);

  /*!
   * @brief The normal vector.
   */
  float3 Normal SEMANTIC_NORMAL(1);

  /*!
   * @brief The texture coordinates.
   */
  float2 Coords SEMANTIC_TEXCOORD(0);
};

#endif
