// -------------------------------------------------------------------------------------------------
//          _____          _______                                   ____   _____
//      ,-:` \;',`'-,     |__  _(_)                                 |___ \ |  __ \
//    .'-;_,;  ':-;_,'.      | | _  _ __   _ __ ___    __ _  _ __     __) || |  | |
//   /;   '/    ,  _`.-\     | || || '_ \ | '_ ` _ \  / _` || '_ \   |__ < | |  | |
//  | '`. (`     /` ` \`|    | || || | | || | | | | || (_| || | | |  ___) || |__| |
//  |:.  `\`-.   \_   / |    |_||_||_| |_||_| |_| |_| \__,_||_| |_| |____/ |_____/
//  |     (   `,  .`\ ;'|
//   \     | .'     `-'/      Realtime terrain processing, rendering and analysis
//    `.   ;/        .'
//      `'-._____.-'`             http://www.tinman3d.com - info@tinman3d.com
// -------------------------------------------------------------------------------------------------
// FILE:       Terrain.PS_Background.hlsl
// -------------------------------------------------------------------------------------------------
// COPYRIGHT:  Matthias Englert, me@tinman3d.com
// -------------------------------------------------------------------------------------------------
// AUTHOR(s):  Matthias Englert, me@tinman3d.com
// -------------------------------------------------------------------------------------------------
// DISCLAIMER: This source  code is  provided "as  is" and  without warranties  as to performance or
//             merchantability. The  author and/or  distributors of  this source  code may have made
//             statements about this source code.  Any such statements do not  constitute warranties
//             and shall not be  relied on by  the user in deciding whether to use this source code.
//             This source code is provided without any expressed or implied warranties  whatsoever.
//             Because of the diversity of conditions and hardware under which this source code  may
//             be used,  no warranty  of fitness  for a  particular purpose  is offered. The user is
//             advised to test the source code thoroughly before relying on it. The user must assume
//             the entire risk of using the source code.
// -------------------------------------------------------------------------------------------------

#ifndef TINMAN__TERRAIN__TERRAIN_PS_BACKGROUND
#define TINMAN__TERRAIN__TERRAIN_PS_BACKGROUND

#include "../../GpuX.hlsl"
#include "../CB_Lighting_Static.hlsl"
#include "../Lighting.hlsl"
#include "../PS_Out_TargetDepth.hlsl"
#include "Material.hlsl"
#include "PS_In_Background.hlsl"
#include "Terrain.hlsl"

// -------------------------------------------------------------------------------------------------
// Pixel Shader 'Terrain.PS_Background'
// -------------------------------------------------------------------------------------------------

/*!
 * @brief The pixel shader for 'TerrainParameters.PassTextureDome'.
 *
 * @param data The shader input.
 *
 * @returns The shader output.
 */
PS_Out_TargetDepth main(PS_In_Background data)
{
  PS_Out_TargetDepth result;
  Material material;
  float opacity;
  float occlusion;

  material = TextureSample(data.Color, data.TexCoords, data.Distance, opacity);
  occlusion = (g_scale.x + g_scale.y) / 2.0;
  result.Color = float4(ComputeToneMap(material.Albedo * occlusion), opacity);
  result.Depth = 1.0;

  return result;
}

#endif
