// -------------------------------------------------------------------------------------------------
//          _____          _______                                   ____   _____
//      ,-:` \;',`'-,     |__  _(_)                                 |___ \ |  __ \
//    .'-;_,;  ':-;_,'.      | | _  _ __   _ __ ___    __ _  _ __     __) || |  | |
//   /;   '/    ,  _`.-\     | || || '_ \ | '_ ` _ \  / _` || '_ \   |__ < | |  | |
//  | '`. (`     /` ` \`|    | || || | | || | | | | || (_| || | | |  ___) || |__| |
//  |:.  `\`-.   \_   / |    |_||_||_| |_||_| |_| |_| \__,_||_| |_| |____/ |_____/
//  |     (   `,  .`\ ;'|
//   \     | .'     `-'/      Realtime terrain processing, rendering and analysis
//    `.   ;/        .'
//      `'-._____.-'`             http://www.tinman3d.com - info@tinman3d.com
// -------------------------------------------------------------------------------------------------
// FILE:       Terrain.PS_Decal.hlsl
// -------------------------------------------------------------------------------------------------
// COPYRIGHT:  Matthias Englert, me@tinman3d.com
// -------------------------------------------------------------------------------------------------
// AUTHOR(s):  Matthias Englert, me@tinman3d.com
// -------------------------------------------------------------------------------------------------
// DISCLAIMER: This source  code is  provided "as  is" and  without warranties  as to performance or
//             merchantability. The  author and/or  distributors of  this source  code may have made
//             statements about this source code.  Any such statements do not  constitute warranties
//             and shall not be  relied on by  the user in deciding whether to use this source code.
//             This source code is provided without any expressed or implied warranties  whatsoever.
//             Because of the diversity of conditions and hardware under which this source code  may
//             be used,  no warranty  of fitness  for a  particular purpose  is offered. The user is
//             advised to test the source code thoroughly before relying on it. The user must assume
//             the entire risk of using the source code.
// -------------------------------------------------------------------------------------------------

#ifndef TINMAN__TERRAIN__TERRAIN_PS_DECAL
#define TINMAN__TERRAIN__TERRAIN_PS_DECAL

#include "../../GpuX.hlsl"
#include "../CB_Lighting_Dynamic.hlsl"
#include "../Configuration.hlsl"
#include "../PS_Out_Target.hlsl"
#include "../Shadow.hlsl"
#include "CB_Decal_Dynamic.hlsl"
#include "CB_Decal_Volatile.hlsl"
#include "PS_In_Decal.hlsl"
#include "SR_Terrain.hlsl"
#include "Terrain.hlsl"

// -------------------------------------------------------------------------------------------------
// Pixel Shader 'Terrain.PS_Decal'
// -------------------------------------------------------------------------------------------------

/*!
 * @brief The pixel shader for 'TerrainParameters.PassColor'.
 *
 * @param data The shader input.
 *
 * @returns The shader output.
 */
PS_Out_Target main(centroid PS_In_Decal data)
{
  PS_Out_Target result;
  float3 uv;

  uv = mul(g_decalWarp, float3(data.Coords, 1));
  uv.xy /= uv.z;

  clip(uv.x - g_decalClip.x);
  clip(uv.y - g_decalClip.y);
  clip(1.0 - g_decalClip.z - uv.x);
  clip(1.0 - g_decalClip.w - uv.y);

  if (!TERRAIN_TEXTURE_ARRAYS || g_decalSlices.x < 0.0)
    result.Color = gxTexture2DArray(g_decal, 0, uv.xy);
  else
  {
    result.Color = gxTexture2DArray(g_decal, g_decalSlices[0], uv.xy) * g_decalWeights[0];

    for (int i = 1; i < 4; i++)
    {
      result.Color += gxTexture2DArray(g_decal, g_decalSlices[i], uv.xy) * g_decalWeights[i];
    }
  }

  result.Color *= g_decalColor;

  if (g_lightEnable != 0.0)
  {
    result.Color.rgb = ComputeColor(data.Color.rgb, 0.0, 0.0, 0.0, 0.0, normalize(data.Eye),
        normalize(data.Normal), data.Distance, ComputeShadow(data.Shadow));
  }

  return result;
}

#endif
