// -------------------------------------------------------------------------------------------------
//          _____          _______                                   ____   _____
//      ,-:` \;',`'-,     |__  _(_)                                 |___ \ |  __ \
//    .'-;_,;  ':-;_,'.      | | _  _ __   _ __ ___    __ _  _ __     __) || |  | |
//   /;   '/    ,  _`.-\     | || || '_ \ | '_ ` _ \  / _` || '_ \   |__ < | |  | |
//  | '`. (`     /` ` \`|    | || || | | || | | | | || (_| || | | |  ___) || |__| |
//  |:.  `\`-.   \_   / |    |_||_||_| |_||_| |_| |_| \__,_||_| |_| |____/ |_____/
//  |     (   `,  .`\ ;'|
//   \     | .'     `-'/      Realtime terrain processing, rendering and analysis
//    `.   ;/        .'
//      `'-._____.-'`             http://www.tinman3d.com - info@tinman3d.com
// -------------------------------------------------------------------------------------------------
// FILE:       Terrain.VS_Decal.hlsl
// -------------------------------------------------------------------------------------------------
// COPYRIGHT:  Matthias Englert, me@tinman3d.com
// -------------------------------------------------------------------------------------------------
// AUTHOR(s):  Matthias Englert, me@tinman3d.com
// -------------------------------------------------------------------------------------------------
// DISCLAIMER: This source  code is  provided "as  is" and  without warranties  as to performance or
//             merchantability. The  author and/or  distributors of  this source  code may have made
//             statements about this source code.  Any such statements do not  constitute warranties
//             and shall not be  relied on by  the user in deciding whether to use this source code.
//             This source code is provided without any expressed or implied warranties  whatsoever.
//             Because of the diversity of conditions and hardware under which this source code  may
//             be used,  no warranty  of fitness  for a  particular purpose  is offered. The user is
//             advised to test the source code thoroughly before relying on it. The user must assume
//             the entire risk of using the source code.
// -------------------------------------------------------------------------------------------------

#ifndef TINMAN__TERRAIN__TERRAIN_VS_DECAL
#define TINMAN__TERRAIN__TERRAIN_VS_DECAL

#include "../../GpuX.hlsl"
#include "../Camera.hlsl"
#include "CB_Decal_Volatile.hlsl"
#include "Displacement.hlsl"
#include "DisplacementFixed.hlsl"
#include "DisplacementVarying.hlsl"
#include "PS_In_Decal.hlsl"
#include "Terrain.hlsl"
#include "VS_In.hlsl"

// -------------------------------------------------------------------------------------------------
// Vertex Shader 'Terrain.VS_Decal'
// -------------------------------------------------------------------------------------------------

/*!
 * @brief The vertex shader for 'TerrainParameters.PassDecal'.
 *
 * @param data The shader input.
 *
 * @returns The shader output.
 */
PS_In_Decal main(VS_In data)
{
  PS_In_Decal result;
  Displacement displacement;

  displacement = ComputeDisplacement(data);
  result.Position = ProjectPosition(displacement.Varying.Position);
  result.Color = float4(1, 1, 1, data.Color.a);
  result.Normal = displacement.Fixed.Normal;
  result.Eye = displacement.Fixed.Eye;
  result.Distance = displacement.Fixed.Distance;
  result.Shadow = displacement.Varying.Shadow;
  result.Coords = float2(dot(data.CoordsHigh, g_decalU) + g_decalOffset.x + (dot(data.CoordsLow,
      g_decalU) + g_decalOffset.z), dot(data.CoordsHigh, g_decalV) + g_decalOffset.y + (dot(data.
      CoordsLow, g_decalV) + g_decalOffset.w));

  return result;
}

#endif
