// -------------------------------------------------------------------------------------------------
//          _____          _______                                   ____   _____
//      ,-:` \;',`'-,     |__  _(_)                                 |___ \ |  __ \
//    .'-;_,;  ':-;_,'.      | | _  _ __   _ __ ___    __ _  _ __     __) || |  | |
//   /;   '/    ,  _`.-\     | || || '_ \ | '_ ` _ \  / _` || '_ \   |__ < | |  | |
//  | '`. (`     /` ` \`|    | || || | | || | | | | || (_| || | | |  ___) || |__| |
//  |:.  `\`-.   \_   / |    |_||_||_| |_||_| |_| |_| \__,_||_| |_| |____/ |_____/
//  |     (   `,  .`\ ;'|
//   \     | .'     `-'/      Realtime terrain processing, rendering and analysis
//    `.   ;/        .'
//      `'-._____.-'`             http://www.tinman3d.com - info@tinman3d.com
// -------------------------------------------------------------------------------------------------
// FILE:       Terrain.VS_Material2.hlsl
// -------------------------------------------------------------------------------------------------
// COPYRIGHT:  Matthias Englert, me@tinman3d.com
// -------------------------------------------------------------------------------------------------
// AUTHOR(s):  Matthias Englert, me@tinman3d.com
// -------------------------------------------------------------------------------------------------
// DISCLAIMER: This source  code is  provided "as  is" and  without warranties  as to performance or
//             merchantability. The  author and/or  distributors of  this source  code may have made
//             statements about this source code.  Any such statements do not  constitute warranties
//             and shall not be  relied on by  the user in deciding whether to use this source code.
//             This source code is provided without any expressed or implied warranties  whatsoever.
//             Because of the diversity of conditions and hardware under which this source code  may
//             be used,  no warranty  of fitness  for a  particular purpose  is offered. The user is
//             advised to test the source code thoroughly before relying on it. The user must assume
//             the entire risk of using the source code.
// -------------------------------------------------------------------------------------------------

#ifndef TINMAN__TERRAIN__TERRAIN_VS_MATERIAL2
#define TINMAN__TERRAIN__TERRAIN_VS_MATERIAL2

#include "../../GpuX.hlsl"
#include "../Util.hlsl"
#include "CB_Material_Volatile1.hlsl"
#include "DisplacementFixed.hlsl"
#include "GS_In_Material.hlsl"
#include "Terrain.hlsl"
#include "VS_In.hlsl"

// -------------------------------------------------------------------------------------------------
// Vertex Shader 'Terrain.VS_Material2'
// -------------------------------------------------------------------------------------------------

/*!
 * @brief The vertex shader for 'TerrainParameters.PassMaterial' or 'TerrainFeatureLevel.DX10',
 *        'TerrainFeatureLevel.DX11' and 'TerrainFeatureLevel.DX12'.
 *
 * @param data The shader input.
 *
 * @returns The shader output.
 */
GS_In_Material main(VS_In data)
{
  GS_In_Material result;

  data.Normal = DecodeShift(data.Normal);
  data.NormalBase = DecodeShift(data.NormalBase);
  result.Fixed = ComputeDisplacementFixed(data.Position, data.PositionDelta, data.Normal, data.
      NormalBase, data.MaterialIds, data.LevelOfDetail);
  result.Color = FromSrgb(data.Color);
  result.WeightsA = data.MaterialWeights;
  result.WeightsB = MaterialComputeWeights(result.Fixed.MaterialIds, data.MaterialWeights,
      g_materialIds);

  return result;
}

#endif
