// -------------------------------------------------------------------------------------------------
//          _____          _______                                   ____   _____
//      ,-:` \;',`'-,     |__  _(_)                                 |___ \ |  __ \
//    .'-;_,;  ':-;_,'.      | | _  _ __   _ __ ___    __ _  _ __     __) || |  | |
//   /;   '/    ,  _`.-\     | || || '_ \ | '_ ` _ \  / _` || '_ \   |__ < | |  | |
//  | '`. (`     /` ` \`|    | || || | | || | | | | || (_| || | | |  ___) || |__| |
//  |:.  `\`-.   \_   / |    |_||_||_| |_||_| |_| |_| \__,_||_| |_| |____/ |_____/
//  |     (   `,  .`\ ;'|
//   \     | .'     `-'/      Realtime terrain processing, rendering and analysis
//    `.   ;/        .'
//      `'-._____.-'`             http://www.tinman3d.com - info@tinman3d.com
// -------------------------------------------------------------------------------------------------
// FILE:       VS_In.hlsl
// -------------------------------------------------------------------------------------------------
// COPYRIGHT:  Matthias Englert, me@tinman3d.com
// -------------------------------------------------------------------------------------------------
// AUTHOR(s):  Matthias Englert, me@tinman3d.com
// -------------------------------------------------------------------------------------------------
// DISCLAIMER: This source  code is  provided "as  is" and  without warranties  as to performance or
//             merchantability. The  author and/or  distributors of  this source  code may have made
//             statements about this source code.  Any such statements do not  constitute warranties
//             and shall not be  relied on by  the user in deciding whether to use this source code.
//             This source code is provided without any expressed or implied warranties  whatsoever.
//             Because of the diversity of conditions and hardware under which this source code  may
//             be used,  no warranty  of fitness  for a  particular purpose  is offered. The user is
//             advised to test the source code thoroughly before relying on it. The user must assume
//             the entire risk of using the source code.
// -------------------------------------------------------------------------------------------------

#ifndef TINMAN__TERRAIN__VS_IN
#define TINMAN__TERRAIN__VS_IN

#include "../../GpuX.hlsl"

// -------------------------------------------------------------------------------------------------
// Shader Parameters
// -------------------------------------------------------------------------------------------------

/*!
 * @brief Vertex shader input for 'ITerrainEffect'.
 */
struct VS_In
{
  /*!
   * @brief The per-vertex data for 'Semantic.Texture'.
   */
  float4 Color SEMANTIC_COLOR(0);

  /*!
   * @brief The per-vertex data for 'Semantic.Material'.
   *
   * @see 'MaterialToken.MaterialAt'
   */
  int4 MaterialIds SEMANTIC_COLOR(1);

  /*!
   * @brief The per-vertex data for 'Semantic.Material'.
   *
   * @see 'MaterialToken.WeightAt'
   */
  float4 MaterialWeights SEMANTIC_COLOR(2);

  /*!
   * @brief The per-vertex data for 'Semantic.HeightmapCoords'.
   */
  float3 CoordsHigh SEMANTIC_TEXCOORD(0);

  /*!
   * @brief The per-vertex data for 'Semantic.HeightmapCoords'.
   */
  float3 CoordsLow SEMANTIC_TEXCOORD(1);

  /*!
   * @brief The per-vertex data for 'Semantic.Normal'.
   */
  float3 Normal SEMANTIC_NORMAL(0);

  /*!
   * @brief The per-vertex data for 'Semantic.NormalBase'.
   */
  float3 NormalBase SEMANTIC_NORMAL(1);

  /*!
   * @brief The per-vertex data for 'Semantic.Position'.
   */
  float3 Position SEMANTIC_POSITION(0);

  /*!
   * @brief The per-vertex data for 'Semantic.Position'.
   */
  float3 PositionDelta SEMANTIC_POSITION(1);

  /*!
   * @brief The per-vertex data for 'Semantic.Area'.
   */
  float2 LevelOfDetail SEMANTIC_TEXCOORD(2);
};

#endif
